@@ -10,8 +10,8 @@ import pandas as pd
 import torch
 from matplotlib import pyplot as plt
 import seaborn as sns
-from dlogicutils.core import *
-from dlogicutils.ju import in_ipynb
+from dl2050utils.core import *
+from dl2050utils.ju import in_ipynb
 T = torch.tensor
 
 def get_sample(x1, y1, x2, y2, sz=1000, sz2=None):
