@@ -76,9 +76,14 @@ def df_stats_cum(probs, actuals, th=.5, thresholds=None):
     df = pd.DataFrame(z, columns=cols)
     if thresholds:
         ths = [t/thresholds if t>0 else -.00001 for t in range(0,thresholds)[::-1]]
-        idxs = [max(np.where(probs>t)[0]) for t in ths]
+        ths2, idxs = [], []
+        for t in ths:
+            idxs1 = np.where(probs>t)[0]
+            if len(idxs1):
+                ths2.append(t)
+                idxs.append(max(idxs1))
         df = df.iloc[idxs].copy()
-        df.insert(0, 'threshold', ths)
+        df.insert(0, 'threshold', ths2)
         df.drop(columns=['prob','pred','actual'], inplace=True)
     return df
 
@@ -212,10 +217,10 @@ def df_predict_clsf(learner, df, have_actuals=False):
     return df
 
 
-
 class Results_Clsf():
-    def __init__(self, data, probs, actuals):
-        self.data, self.probs, self.actuals = data, probs, actuals
+    def __init__(self, probs, actuals):
+        self.probs, self.actuals = probs, actuals
+        self.c = len(np.unique(actuals))
         self.preds = get_preds(probs)
 #         self.probs_for_actuals = get_probs_for_actuals(y2, self.actuals)
 #         self.probs_sorted = np.argsort(self.probs_for_actuals)[::-1]
@@ -229,18 +234,18 @@ class Results_Clsf():
         if t is None:
             preds = self.preds
         else:
-            if self.data.c!=2: raise ValueError('More than two classes')
+            if self.c!=2: raise ValueError('More than two classes')
             preds = (self.probs>t)*1
-        cm = plot_confusion(self.data.c, self.actuals, preds)
+        cm = plot_confusion(self.c, self.actuals, preds)
         display(df_stats_by_class(cm))
     def df_stats(self, thresholds=10):
-        if self.data.c!=2: raise ValueError('More than two classes')
+        if self.c!=2: raise ValueError('More than two classes')
         return df_stats_cum(self.probs, self.actuals, thresholds=thresholds)
     def roc(self):
-        if self.data.c!=2: raise ValueError('More than two classes')
+        if self.c!=2: raise ValueError('More than two classes')
         plot_roc(self.actuals, self.probs)
-#     def show_best(self, n=8, **kwargs):  self.show_set(self.data.ds2, self.probs_sorted[:n], **kwargs)
-#     def show_worst(self, n=8, **kwargs): self.show_set(self.data.ds2, self.probs_sorted[-n:][::-1], **kwargs)
+#     def show_best(self, n=8, **kwargs):  self.show_set(self.ds2, self.probs_sorted[:n], **kwargs)
+#     def show_worst(self, n=8, **kwargs): self.show_set(self.ds2, self.probs_sorted[-n:][::-1], **kwargs)
 #     def show_set(self, ds, idxs, **kwargs):
 #         labels = [f'{ds.labels[i]}:{self.actuals[i]} -> {ds.cls[self.preds[i]]}:{self.preds[i]} (p={self.probs_for_actuals[i]:.4f})'
 #                     for i in idxs]
@@ -252,8 +257,7 @@ class Results_Clsf_Tabular(Results_Clsf):
         assert 'prob' in df.columns
         assert data.proc.c_dep in df.columns
         self.proc, self.df = data.proc, df
-        super(Results_Clsf_Tabular, self).__init__(data, df['prob'].values, df[data.proc.c_dep].values)
-        # self.df['prob'] = self.probs if self.data.c>2 else self.probs_bin
+        super(Results_Clsf_Tabular, self).__init__(df['prob'].values, df[data.proc.c_dep].values)
     # def corr_cat(self): get_corr(self.df, self.proc.c_cat, plot=True)
     # def corr_cont(self): get_corr(self.df, self.proc.c_cont, plot=True)
     # def corr_prob(self): get_corr(self.df, self.proc.c_cat+self.proc.c_cont+[self.proc.c_dep, 'prob'], c='prob', plot=True)
